@@ -58,6 +58,7 @@ class SyslogHandler(logging.Handler):
 
 
 class JournalHandler(logging.Handler):
+    """Journald based handler. Only available on platforms using systemd."""
 
     def __init__(self, program_name):
         if not journal:
@@ -87,10 +88,10 @@ class JournalHandler(logging.Handler):
         if record.exc_info:
             extras['EXCEPTION_INFO'] = record.exc_info
 
-        if hasattr(record, "_daiquiri_extra"):
-            for k, v in record._daiquiri_extra.items():
-                if k != "_daiquiri_extra":
-                    extras[k.upper()] = v
+        if hasattr(record, "_daiquiri_extra_keys"):
+            for k, v in record._daiquiri_extra_keys:
+                if k != "_daiquiri_extra_keys":
+                    extras[k.upper()] = getattr(record, k)
 
         journal.send(message, **extras)
 
@@ -100,7 +101,11 @@ class TTYDetectorStreamHandler(logging.StreamHandler):
 
     def format(self, record):
         if hasattr(self.stream, "isatty"):
-            record._stream_is_a_tty = self.stream.isatty()
+            try:
+                record._stream_is_a_tty = self.stream.isatty()
+            except ValueError:
+                # Stream has been closed, usually during interpretor shutdown
+                record._stream_is_a_tty = False
         else:
             record._stream_is_a_tty = False
         s = super(TTYDetectorStreamHandler, self).format(record)
